@@ -53,17 +53,17 @@ static char *ProgramName;
 static void print_scanline (unsigned int width, unsigned int height,
 			    unsigned const char *data, const char *chars);
 
-static void
-usage (void)
+static void _X_NORETURN
+usage (int exitval)
 {
-    fprintf (stderr, "usage:  %s [-options ...] [filename]\n\n",
-	     ProgramName);
-    fprintf (stderr,
-	"where options include:\n");
-    fprintf (stderr,
-	"    -chars cc        chars to use for 0 and 1 bits, respectively\n");
-    fprintf (stderr, "\n");
-    exit (1);
+    fprintf (stderr, "usage:  %s [-options ...] [filename]\n\n%s\n",
+	     ProgramName,
+	"where options include:\n"
+	"    -chars cc        chars to use for 0 and 1 bits, respectively\n"
+	"    -help            print this usage message\n"
+	"    -version         print version information\n"
+        );
+    exit (exitval);
 }
 
 static char *
@@ -75,28 +75,23 @@ copy_stdin (void)
     static char tmpfilename[] = "/tmp/bmtoa.XXXXXX";
 #endif
     char buf[BUFSIZ];
-    FILE *fp;
+    FILE *fp = NULL;
     int nread, nwritten;
 
 #ifndef HAVE_MKSTEMP
-    if (mktemp (tmpfilename) == NULL) {
-	fprintf (stderr,
-		 "%s:  unable to genererate temporary file name for stdin.\n",
-		 ProgramName);
-	exit (1);
-    }
-    fp = fopen (tmpfilename, "w");
+    if (mktemp (tmpfilename) != NULL)
+	fp = fopen (tmpfilename, "w");
 #else
     int fd;
-
-    if ((fd = mkstemp(tmpfilename)) < 0) {
+    if ((fd = mkstemp(tmpfilename)) >= 0)
+	fp = fdopen(fd, "w");
+#endif
+    if (fp == NULL) {
 	fprintf (stderr,
-		 "%s:  unable to genererate temporary file name for stdin.\n",
+		 "%s:  unable to generate temporary file for stdin.\n",
 		 ProgramName);
 	exit (1);
     }
-    fp = fdopen(fd, "w");
-#endif
     while (1) {
 	buf[0] = '\0';
 	nread = fread (buf, 1, sizeof buf, stdin);
@@ -138,11 +133,29 @@ main (int argc, char *argv[])
 		filename = NULL;
 		continue;
 	      case 'c':
-		if (++i >= argc) usage ();
+		if (++i >= argc) {
+		    fprintf(stderr, "%s: -chars requires an argument\n",
+			    ProgramName);
+		    usage(1);
+		}
 		chars = argv[i];
 		continue;
+	      case 'h':
+		if (strcmp(arg, "-help") == 0) {
+		    usage(0);
+		}
+		goto unknown;
+	      case 'v':
+		if (strcmp(arg, "-version") == 0) {
+		    puts(PACKAGE_STRING);
+		    exit(0);
+		}
+                goto unknown;
 	      default:
-		usage ();
+	      unknown:
+		fprintf(stderr, "%s: unrecognized option '%s'\n",
+			ProgramName, argv[i]);
+		usage(1);
 	    }
 	} else {
 	    filename = arg;
@@ -181,14 +194,13 @@ print_scanline (unsigned int width,
 		const char *chars)
 {
     unsigned const char *dp = data;
-    int row, column;
     static unsigned const char masktable[] = {
 	0x01, 0x02, 0x04, 0x08, 0x10, 0x20, 0x40, 0x80 };
     int padded = ((width & 7) != 0);
 
-    for (row = 0; row < height; row++) {
-	for (column = 0; column < width; column++) {
-	    int i = (column & 7);
+    for (unsigned int row = 0; row < height; row++) {
+	for (unsigned int column = 0; column < width; column++) {
+	    unsigned int i = (column & 7);
 
 	    if (*dp & masktable[i]) {
 		putchar (chars[1]);
